ExtentIndex

Struct ExtentIndex 

pub struct ExtentIndex {
    pub block: u32,
    pub leaf_lo: u32,
    pub leaf_hi: u16,
    pub unused: u16,
}
An internal (index) entry in the extent tree, pointing to the next level.

Fields

block: u32

Logical block number – this index covers blocks >= block.

leaf_lo: u32

Lower 32 bits of the physical block containing the child node.

leaf_hi: u16

Upper 16 bits of the physical block containing the child node.

unused: u16

Implementations

Source

impl ExtentIndex

pub const SIZE: usize = 12

pub fn read_from(buf: &[u8]) -> Self

pub fn write_to(&self, buf: &mut [u8])

pub fn leaf(&self) -> u64

Full 48-bit physical block of the child node.