ExtentLeaf

Struct ExtentLeaf 

pub struct ExtentLeaf {
    pub block: u32,
    pub len: u16,
    pub start_hi: u16,
    pub start_lo: u32,
}
A leaf entry in the extent tree, mapping logical blocks to physical blocks.

Fields

block: u32

First logical block number that this extent covers.

len: u16

Number of blocks covered by this extent. If the high bit is set, the extent is uninitialized (pre-allocated).

start_hi: u16

Upper 16 bits of the 48-bit physical block number.

start_lo: u32

Lower 32 bits of the 48-bit physical block number.

Implementations

Source

impl ExtentLeaf

pub const SIZE: usize = 12

pub fn read_from(buf: &[u8]) -> Self

pub fn write_to(&self, buf: &mut [u8])

pub fn start(&self) -> u64

Full 48-bit physical start block.