pub struct ExtentIndex {
pub block: u32,
pub leaf_lo: u32,
pub leaf_hi: u16,
pub unused: u16,
}Expand description
An internal (index) entry in the extent tree, pointing to the next level.
Fields
block: u32Logical block number – this index covers blocks >= block.
leaf_lo: u32Lower 32 bits of the physical block containing the child node.
leaf_hi: u16Upper 16 bits of the physical block containing the child node.
unused: u16Implementations