pub struct ExtentLeaf {
pub block: u32,
pub len: u16,
pub start_hi: u16,
pub start_lo: u32,
}Expand description
A leaf entry in the extent tree, mapping logical blocks to physical blocks.
Fields
block: u32First logical block number that this extent covers.
len: u16Number of blocks covered by this extent. If the high bit is set, the extent is uninitialized (pre-allocated).
start_hi: u16Upper 16 bits of the 48-bit physical block number.
start_lo: u32Lower 32 bits of the 48-bit physical block number.
Implementations