pub struct XAttrEntry {
pub name_len: u8,
pub name_index: u8,
pub value_offset: u16,
pub value_inum: u32,
pub value_size: u32,
pub hash: u32,
}Expand description
On-disk extended-attribute entry. The name bytes follow immediately after this header, then padding to a 4-byte boundary.
Fields
name_len: u8Length of the attribute name.
name_index: u8Attribute name index (e.g. 1 = “user.”, 2 = “system.posix_acl_access”).
value_offset: u16Offset of the value within the value area (from end of entry table).
value_inum: u32Inode holding the value (0 when value is inline in this block).
value_size: u32Size of the attribute value in bytes.
hash: u32Hash of the attribute name and value.
Implementations